Learn R Programming

parfossil (version 0.2.0)

parfossil-package: Parallelized functions for palaeoecological and palaeogeographical analysis

Description

This package provides a number of functions from the fossil package that have been designed to be run on a parallel backend. The functions show a large speed up, even when just using a dual core versus single core set up, which can be very useful in situations with a large number of resampling replicates.

Arguments

Details

The package requires some parallel backend to be loaded, using packages such as multicore, Rmpi or snow