Usage
par.nmds(dmat, mindim = 1, maxdim = 2, nits = 10, iconf = 0, epsilon = 1e-12, maxit = 500, trace = FALSE)
Arguments
dmat
Lower triangle distance matrix
mindim
optional, the minmum number of dimensions to use for an analysis; default is 1
maxdim
optional, the maximum number of dimensions to use for an analysis; default is 2
nits
optional, the number of iterations; how many times the data should be initially placed at random; default is 10
iconf
optional, initial configuration. If not specified, then a random configuration is used.
epsilon
optional, acceptable difference in stress.
maxit
optional, maximum number of iterations.
trace
if TRUE, will write progress indicator to the screen.