## Not run:
# #comparison of run times between the serial and parallel versions on the estimator
# #please note that this example is designed for a multicore OS X or Linux computer
# library(doMC)
# registerDoMC()
# data(fdata.mat)
# system.time({spp.est(fdata.mat, rand = 100, abund = TRUE, counter = FALSE)})
# system.time({par.spp.est(fdata.mat, rand = 100, abund = TRUE, counter = FALSE)})
#
# #this example is for a multicore Windows computer, but HAS NOT BEEN TESTED
# library(doSNOW)
# library(snow)
# cl <- makeCluster(c("localhost","localhost"), type = "SOCK")
# registerDoSNOW(c1)
# data(fdata.mat)
# system.time({spp.est(fdata.mat, rand = 100, abund = TRUE, counter = FALSE)})
# system.time({par.spp.est(fdata.mat, rand = 100, abund = TRUE, counter = FALSE)})
# stopCluster(cl)
#
# ## End(Not run)
Run the code above in your browser using DataLab